import { Component, OnInit, ElementRef, ViewChild } from '@angular/core';
import { RecipeInterface } from '../../interfaces/recipe';
import { RecipeService } from '../../services/recipe.service';
import { Router } from '@angular/router';
import { AuthService } from '../../services/auth.service';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { AngularFireStorage } from '@angular/fire/storage';
import { finalize } from 'rxjs/operators';
import { Observable } from 'rxjs/Observable';


@Component({
  selector: 'app-newrecipe',
  templateUrl: './newrecipe.component.html',
  styleUrls: ['./newrecipe.component.css']
})
export class NewrecipeComponent implements OnInit {

  url = '';

  recipe: RecipeInterface = {
    id: '',
    title: '',
    description: '',
    preparation: '',
    ingredients: '',
    publicationDate: '',
    userId: '',
    userEmail: '',
    imageUrl: '',
    userFavorite: Array[''],
  };

  constructor(
    private authService: AuthService,
    private recipeService: RecipeService,
    private router: Router,
    private storage: AngularFireStorage,
  ) { }

  @ViewChild('imageRecipe') inputImageRecipe: ElementRef;

  uploadPercent: Observable<number>;
  urlImage: Observable<string>;

  ngOnInit() {
    console.log(new Date().getTime());
  }

  onUpload(e) {
    console.log('subir', e.target.files[0]);
    const id = Math.random().toString(36).substring(2);
    const file = e.target.files[0];
    const filePath = `gestcook/profile_${id}`;
    const ref = this.storage.ref(filePath);
    const task = this.storage.upload(filePath, file);
    this.uploadPercent = task.percentageChanges();
    task.snapshotChanges().pipe(finalize(() => this.urlImage = ref.getDownloadURL())).subscribe();
  }

  onGuardarReceta({value}: {value: RecipeInterface}) {
    value.publicationDate = (new Date()).getTime();
    this.authService.getAuth().subscribe( user => {
      value.userId = user.uid;
      value.userEmail = user.email;
      value.imageUrl = this.inputImageRecipe.nativeElement.value;
      value.id = this.recipe.id;
      // value.imageUrl = this.urlImage;
      this.recipeService.addNewRecipe(value);
    });
    this.router.navigate(['/recipes']);
    console.log(value);
  }

  onSelectFile(event) {
    if (event.target.files && event.target.files[0]) {
      const reader = new FileReader();

      reader.readAsDataURL(event.target.files[0]); // read file as data url

      reader.onload = (event: any) => { // called once readAsDataURL is completed
        this.url = event.target.result;
        console.log('url', this.url);
      };
    }

  }




}

